@@ -79,6 +79,11 @@ class CheckMXRecords(BaseCommand):
             pattern = "{}.{}.".format(reverse, provider)
             try:
                 result = socket.gethostbyname(pattern)
+                #result from dnsbl is in ipv4 format
+                splited_result = result.split(".")
+                if int(splited_result[-1]) > 15:
+                    #Typical dnsbl result : 127.0.0.[1-15] (depends on services)
+                    result = False
             except socket.gaierror:
                 result = False
             for mx in mxs:
