@@ -2,7 +2,6 @@
 
 from django.conf import settings
 from django.db import models
-from django.utils.encoding import python_2_unicode_compatible
 from django.utils.functional import cached_property
 from django.utils.translation import ugettext as _
 
@@ -14,7 +13,7 @@ class ObjectLimitMixin(object):
     """Common methods."""
 
     @property
-    def label(self):
+    def label(self) -> str:
         """Return display name."""
         return self.definition["label"]
 
@@ -24,7 +23,7 @@ class ObjectLimitMixin(object):
         return self.definition.get("type", "count")
 
     @property
-    def usage(self):
+    def usage(self) -> int:
         """Return current limit usage in %."""
         if self.max_value < 0:
             return -1
@@ -59,7 +58,6 @@ class ObjectLimitMixin(object):
         return "{}%".format(self.usage)
 
 
-@python_2_unicode_compatible
 class UserObjectLimit(ObjectLimitMixin, models.Model):
     """Object level limit."""
 
@@ -81,7 +79,7 @@ class UserObjectLimit(ObjectLimitMixin, models.Model):
         return None
 
     @property
-    def current_value(self):
+    def current_value(self) -> int:
         """Return the current number of objects."""
         condition = (
             self.type == "count" and
@@ -109,7 +107,7 @@ class UserObjectLimit(ObjectLimitMixin, models.Model):
         return self.definition["label"]
 
     @cached_property
-    def usage(self):
+    def usage(self) -> int:
         """Return current limit usage in %."""
         if self.max_value < 0:
             return -1
@@ -143,7 +141,7 @@ class DomainObjectLimit(ObjectLimitMixin, models.Model):
         return None
 
     @property
-    def current_value(self):
+    def current_value(self) -> int:
         """Return the current number of objects."""
         definition = self.definition
         if not definition:
